@@ -28,6 +28,19 @@
 #include <string.h>
 #include <unistd.h>
 
+#ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+# ifndef __BYTE_ORDER
+#  define __BYTE_ORDER BYTE_ORDER
+# endif
+# ifndef __BIG_ENDIAN
+#  define __BIG_ENDIAN BIG_ENDIAN
+# endif
+# ifndef __LITTLE_ENDIAN
+#  define __LITTLE_ENDIAN LITTLE_ENDIAN
+# endif
+#endif
+
 #include "busybox.h"
 
 #ifdef CONFIG_SHA1SUM
