@@ -7,9 +7,9 @@
 
 #include <unistd.h>
 
-void xchdir(const char *path);
-void xchdir(const char *path)
+static void
+xchdir(const char *path)
 {
-	if (chdir(path))
+	if (unlikely(chdir(path) != 0))
 		errp("chdir(%s) failed", path);
 }
