@@ -13,16 +13,11 @@
 static bool eat_file(const char *, char **, size_t *);
 static bool eat_file_fd(int, char **, size_t *);
 static bool eat_file_at(int, const char *, char **, size_t *);
-int rematch(const char *, const char *, int);
+static int rematch(const char *, const char *, int);
 static char *rmspace(char *);
 static char *rmspace_len(char *, size_t);
 
-void initialize_portage_env(void);
-void initialize_ebuild_flat(void);
-void reinitialize_ebuild_flat(void);
-void reinitialize_as_needed(void);
-void cleanup(void);
-int lookup_applet_idx(const char *);
+static int lookup_applet_idx(const char *);
 
 /* variables to control runtime behavior */
 char *module_name = NULL;
@@ -60,8 +55,8 @@ static const char *argv0;
 
 #ifdef EBUG
 # include <sys/resource.h>
-void init_coredumps(void);
-void init_coredumps(void)
+static void
+init_coredumps(void)
 {
 	struct rlimit rl;
 	rl.rlim_cur = RLIM_INFINITY;
@@ -75,14 +70,23 @@ void init_coredumps(void)
 
 static DECLARE_ARRAY(overlays);
 
-_q_static
-void no_colors(void)
+static void
+no_colors(void)
 {
 	/* echo $(awk '{print $4,"="}' libq/colors.c  | grep ^* |cut -c 2-| grep ^[A-Z] |tr '\n' ' ') = \"\"\;  */
 	BOLD = NORM = BLUE = DKBLUE = CYAN = GREEN = DKGREEN = MAGENTA = RED = YELLOW = BRYELLOW = WHITE = "";
 	setenv("NOCOLOR", "true", 1);
 }
 
+static void
+setup_quiet(void)
+{
+	/* "e" for FD_CLOEXEC */
+	if (quiet == 0)
+		warnout = fopen("/dev/null", "we");
+	++quiet;
+}
+
 /* include common applet defs */
 #include "applets.h"
 
@@ -107,15 +111,16 @@ void no_colors(void)
 #define COMMON_GETOPTS_CASES(applet) \
 	case 0x1: portroot = optarg; break; \
 	case 'v': ++verbose; break; \
-	case 'q': if (quiet == 0) { warnout = fopen("/dev/null", "we"); } ++quiet; break; \
+	case 'q': setup_quiet(); break; \
 	case 'V': version_barf(); break; \
 	case 'h': applet ## _usage(EXIT_SUCCESS); break; \
 	case 'C': no_colors(); break; \
 	default: applet ## _usage(EXIT_FAILURE); break;
 
 /* display usage and exit */
-static void usage(int status, const char *flags, struct option const opts[],
-                  const char * const help[], const char *desc, int blabber)
+static void
+usage(int status, const char *flags, struct option const opts[],
+      const char * const help[], const char *desc, int blabber)
 {
 	const char opt_arg[] = "[arg]";
 	const char a_arg[] = "<arg>";
@@ -181,7 +186,8 @@ static void usage(int status, const char *flags, struct option const opts[],
 	exit(status);
 }
 
-static void version_barf(void)
+static void
+version_barf(void)
 {
 #ifndef VERSION
 # define VERSION "git"
@@ -195,7 +201,8 @@ static void version_barf(void)
 	exit(EXIT_SUCCESS);
 }
 
-static bool eat_file_fd(int fd, char **bufptr, size_t *bufsize)
+static bool
+eat_file_fd(int fd, char **bufptr, size_t *bufsize)
 {
 	bool ret = true;
 	struct stat s;
@@ -243,7 +250,8 @@ static bool eat_file_fd(int fd, char **bufptr, size_t *bufsize)
 	return ret;
 }
 
-static bool eat_file_at(int dfd, const char *file, char **bufptr, size_t *bufsize)
+static bool
+eat_file_at(int dfd, const char *file, char **bufptr, size_t *bufsize)
 {
 	bool ret;
 	int fd;
@@ -256,12 +264,14 @@ static bool eat_file_at(int dfd, const char *file, char **bufptr, size_t *bufsiz
 	return ret;
 }
 
-static bool eat_file(const char *file, char **bufptr, size_t *bufsize)
+static bool
+eat_file(const char *file, char **bufptr, size_t *bufsize)
 {
 	return eat_file_at(AT_FDCWD, file, bufptr, bufsize);
 }
 
-static bool prompt(const char *p)
+static bool
+prompt(const char *p)
 {
 	printf("%s? [Y/n] ", p);
 	fflush(stdout);
@@ -275,7 +285,8 @@ static bool prompt(const char *p)
 	}
 }
 
-int rematch(const char *re, const char *match, int cflags)
+static int
+rematch(const char *re, const char *match, int cflags)
 {
 	regex_t preg;
 	int ret;
@@ -292,8 +303,8 @@ int rematch(const char *re, const char *match, int cflags)
 }
 
 /* removes adjacent extraneous white space */
-static char *remove_extra_space(char *str);
-static char *remove_extra_space(char *str)
+static char *
+remove_extra_space(char *str)
 {
 	char *p, c = ' ';
 	size_t len, pos = 0;
@@ -317,14 +328,16 @@ static char *remove_extra_space(char *str)
 	return str;
 }
 
-static void freeargv(int argc, char **argv)
+static void
+freeargv(int argc, char **argv)
 {
 	while (argc--)
 		free(argv[argc]);
 	free(argv);
 }
 
-static void makeargv(const char *string, int *argc, char ***argv)
+static void
+makeargv(const char *string, int *argc, char ***argv)
 {
 	int curc = 2;
 	char *q, *p, *str;
@@ -369,8 +382,8 @@ typedef struct {
 	long mtime;
 } contents_entry;
 
-contents_entry *contents_parse_line(char *line);
-contents_entry *contents_parse_line(char *line)
+static contents_entry *
+contents_parse_line(char *line)
 {
 	static contents_entry e;
 	char *p;
@@ -444,7 +457,8 @@ contents_entry *contents_parse_line(char *line)
 }
 
 /* Handle a single file in the repos.conf format. */
-static void read_one_repos_conf(const char *repos_conf)
+static void
+read_one_repos_conf(const char *repos_conf)
 {
 	int nsec;
 	char *conf;
@@ -478,7 +492,8 @@ static void read_one_repos_conf(const char *repos_conf)
 }
 
 /* Handle a possible directory of files. */
-static void read_repos_conf(const char *configroot, const char *repos_conf)
+static void
+read_repos_conf(const char *configroot, const char *repos_conf)
 {
 	char *top_conf, *sub_conf;
 	int i, count;
@@ -526,7 +541,8 @@ static void read_repos_conf(const char *configroot, const char *repos_conf)
 	free(top_conf);
 }
 
-static void strincr_var(const char *name, const char *s, char **value, size_t *value_len)
+static void
+strincr_var(const char *name, const char *s, char **value, size_t *value_len)
 {
 	size_t len;
 	char *buf, *p, *nv;
@@ -584,7 +600,8 @@ typedef struct {
 	const char *default_value;
 } env_vars;
 
-_q_static env_vars *get_portage_env_var(env_vars *vars, const char *name)
+static env_vars *
+get_portage_env_var(env_vars *vars, const char *name)
 {
 	size_t i;
 
@@ -595,7 +612,8 @@ _q_static env_vars *get_portage_env_var(env_vars *vars, const char *name)
 	return NULL;
 }
 
-_q_static void set_portage_env_var(env_vars *var, const char *value)
+static void
+set_portage_env_var(env_vars *var, const char *value)
 {
 	switch (var->type) {
 	case _Q_BOOL:
@@ -612,7 +630,8 @@ _q_static void set_portage_env_var(env_vars *var, const char *value)
 }
 
 /* Helper to read a portage env file (e.g. make.conf) */
-_q_static void read_portage_env_file(const char *configroot, const char *file, env_vars vars[])
+static void
+read_portage_env_file(const char *configroot, const char *file, env_vars vars[])
 {
 	size_t i, buflen, line, configroot_len, file_len;
 	FILE *fp;
@@ -729,7 +748,8 @@ _q_static void read_portage_env_file(const char *configroot, const char *file, e
 }
 
 /* Helper to recursively read stacked make.defaults in profiles */
-static void read_portage_profile(const char *configroot, const char *profile, env_vars vars[])
+static void
+read_portage_profile(const char *configroot, const char *profile, env_vars vars[])
 {
 	size_t configroot_len, profile_len, sub_len;
 	char *profile_file, *sub_file;
@@ -770,7 +790,8 @@ static void read_portage_profile(const char *configroot, const char *profile, en
 	free(profile_file);
 }
 
-void initialize_portage_env(void)
+static void
+initialize_portage_env(void)
 {
 	size_t i;
 	const char *s;
@@ -823,16 +844,16 @@ void initialize_portage_env(void)
 	/* figure out where to find our config files */
 	const char *configroot = getenv("PORTAGE_CONFIGROOT");
 	if (!configroot)
-		configroot = "/";
+		configroot = CONFIG_EPREFIX "/";
 
 	/* walk all the stacked profiles */
-	read_portage_profile(configroot, CONFIG_EPREFIX "etc/make.profile", vars_to_read);
-	read_portage_profile(configroot, CONFIG_EPREFIX "etc/portage/make.profile", vars_to_read);
+	read_portage_profile(configroot, "/etc/make.profile", vars_to_read);
+	read_portage_profile(configroot, "/etc/portage/make.profile", vars_to_read);
 
 	/* now read all the config files */
 	read_portage_env_file("", CONFIG_EPREFIX "usr/share/portage/config/make.globals", vars_to_read);
-	read_portage_env_file(configroot, CONFIG_EPREFIX "etc/make.conf", vars_to_read);
-	read_portage_env_file(configroot, CONFIG_EPREFIX "etc/portage/make.conf", vars_to_read);
+	read_portage_env_file(configroot, "/etc/make.conf", vars_to_read);
+	read_portage_env_file(configroot, "/etc/portage/make.conf", vars_to_read);
 
 	/* finally, check the env */
 	for (i = 0; vars_to_read[i].name; ++i) {
@@ -940,7 +961,7 @@ void initialize_portage_env(void)
 		xarraypush_str(overlays, main_overlay);
 
 	if (getenv("PORTAGE_QUIET") != NULL)
-		quiet = 1;
+		setup_quiet();
 
 	if (nocolor)
 		no_colors();
@@ -955,8 +976,8 @@ enum {
 	CACHE_METADATA_MD5 = 11,
 };
 
-int filter_hidden(const struct dirent *dentry);
-int filter_hidden(const struct dirent *dentry)
+static int
+filter_hidden(const struct dirent *dentry)
 {
 	if (dentry->d_name[0] == '.')
 		return 0;
@@ -1094,7 +1115,8 @@ ret:
 	return cache_file;
 }
 
-void reinitialize_as_needed(void)
+static void
+reinitialize_as_needed(void)
 {
 	size_t n;
 	const char *overlay, *ret = ret;
@@ -1102,13 +1124,15 @@ void reinitialize_as_needed(void)
 	if (reinitialize)
 		array_for_each(overlays, n, overlay) {
 			ret = initialize_flat(overlay, CACHE_EBUILD, true);
-			IF_DEBUG(free((void *)ret));
+			if (USE_CLEANUP)
+				free((void *)ret);
 		}
 
 	if (reinitialize_metacache)
 		array_for_each(overlays, n, overlay) {
 			ret = initialize_flat(overlay, CACHE_METADATA, true);
-			IF_DEBUG(free((void *)ret));
+			if (USE_CLEANUP)
+				free((void *)ret);
 		}
 }
 
@@ -1138,12 +1162,12 @@ typedef struct {
 	char *_md5_;
 } portage_cache;
 
-void cache_free(portage_cache *cache);
-portage_cache *cache_read_file_pms(const char *file);
-portage_cache *cache_read_file_md5(const char *file);
-portage_cache *cache_read_file(const char *file);
+static void cache_free(portage_cache *cache);
+static portage_cache *cache_read_file_pms(const char *file);
+static portage_cache *cache_read_file_md5(const char *file);
 
-portage_cache *cache_read_file(const char *file)
+static portage_cache *
+cache_read_file(const char *file)
 {
 	if (portcachedir_type == CACHE_METADATA_MD5)
 		return(cache_read_file_md5(file));
@@ -1153,7 +1177,8 @@ portage_cache *cache_read_file(const char *file)
 	return NULL;
 }
 
-portage_cache *cache_read_file_pms(const char *file)
+static portage_cache *
+cache_read_file_pms(const char *file)
 {
 	struct stat s;
 	char *ptr;
@@ -1199,6 +1224,10 @@ portage_cache *cache_read_file_pms(const char *file)
 	next_line(EAPI, PROPERTIES)
 #undef next_line
 	ptr = strchr(ptr+1, '\n');
+	if (ptr == NULL) {
+		warn("Invalid cache file '%s' - could not find end of cache data", file);
+		goto err;
+	}
 	*ptr = '\0';
 
 	fclose(f);
@@ -1211,7 +1240,8 @@ err:
 	return NULL;
 }
 
-portage_cache *cache_read_file_md5(const char *file)
+static portage_cache *
+cache_read_file_md5(const char *file)
 {
 	struct stat s;
 	char *ptr, *endptr;
@@ -1309,8 +1339,9 @@ err:
 	return NULL;
 }
 
-void cache_dump(portage_cache *cache);
-void cache_dump(portage_cache *cache)
+#ifdef EBUG
+static void
+cache_dump(portage_cache *cache)
 {
 	if (!cache)
 		errf("Cache is empty !");
@@ -1337,8 +1368,10 @@ void cache_dump(portage_cache *cache)
 	printf("PV         : %s\n", cache->atom->PV);
 	printf("PVR        : %s\n", cache->atom->PVR);
 }
+#endif
 
-void cache_free(portage_cache *cache)
+static void
+cache_free(portage_cache *cache)
 {
 	if (!cache)
 		errf("Cache is empty !");
@@ -1346,13 +1379,14 @@ void cache_free(portage_cache *cache)
 	free(cache);
 }
 
-char *atom_to_pvr(depend_atom *atom);
-char *atom_to_pvr(depend_atom *atom) {
+static char *
+atom_to_pvr(depend_atom *atom) {
 	return (atom->PR_int == 0 ? atom->P : atom->PVR );
 }
 
 /* TODO: Merge this into libq/vdb.c somehow. */
-_q_static queue *get_vdb_atoms(int fullcpv)
+static queue *
+get_vdb_atoms(int fullcpv)
 {
 	q_vdb_ctx *ctx;
 
@@ -1382,14 +1416,20 @@ _q_static queue *get_vdb_atoms(int fullcpv)
 		if ((dfd = scandirat(ctx->vdb_fd, cat[j]->d_name, &pf, q_vdb_filter_pkg, alphasort)) < 0)
 			continue;
 		for (i = 0; i < dfd; i++) {
-			snprintf(buf, sizeof(buf), "%s/%s", cat[j]->d_name, pf[i]->d_name);
+			int blen = snprintf(buf, sizeof(buf), "%s/%s/SLOT", cat[j]->d_name, pf[i]->d_name);
+			if (blen >= sizeof(buf)) {
+				warnf("unable to parse long package: %s/%s", cat[j]->d_name, pf[i]->d_name);
+				continue;
+			}
+
+			/* Chop the SLOT for the atom parsing. */
+			buf[blen - 5] = '\0';
 			if ((atom = atom_explode(buf)) == NULL)
 				continue;
+			/* Restore the SLOT. */
+			buf[blen - 5] = '/';
 
-			/* XXX: This assumes static slot buf is big enough, but should be fine
-			 * until this is rewritten & merged into libq/vdb.c. */
 			slot_len = sizeof(slot);
-			strncat(buf, "/SLOT", sizeof(buf));
 			eat_file_at(ctx->vdb_fd, buf, &slotp, &slot_len);
 			rmspace(slot);
 
@@ -1413,7 +1453,8 @@ _q_static queue *get_vdb_atoms(int fullcpv)
 	return cpf;
 }
 
-void cleanup(void)
+static void
+cleanup(void)
 {
 	reinitialize_as_needed();
 }
