@@ -30,7 +30,10 @@
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <fnmatch.h>
 #include <getopt.h>
+#include <glob.h>
 #include <inttypes.h>
 #include <libgen.h>
 #include <limits.h>
@@ -74,4 +77,7 @@
 #define CONFIG_EPREFIX "/"
 #endif
 
+#define likely(x) __builtin_expect((x), 1)
+#define unlikely(x) __builtin_expect((x), 0)
+
 #endif
