@@ -8,9 +8,6 @@
 
 #ifdef APPLET_qmerge
 
-#include <fnmatch.h>
-#include <glob.h>
-#include <sys/stat.h>
 /* This is a GNUlib hack, because GNUlib doesn't provide st_mtim members
  * of struct stat, but instead provides wrappers to retrieve the time
  * fields (stat-time module). We just define a macro in case people are
@@ -101,13 +98,14 @@ struct llist_char_t {
 
 typedef struct llist_char_t llist_char;
 
-_q_static void pkg_fetch(int, const depend_atom *, const struct pkg_t *);
-_q_static void pkg_merge(int, const depend_atom *, const struct pkg_t *);
-_q_static int pkg_unmerge(q_vdb_pkg_ctx *, queue *);
-_q_static struct pkg_t *grab_binpkg_info(const char *);
-_q_static char *find_binpkg(const char *);
+static void pkg_fetch(int, const depend_atom *, const struct pkg_t *);
+static void pkg_merge(int, const depend_atom *, const struct pkg_t *);
+static int pkg_unmerge(q_vdb_pkg_ctx *, queue *);
+static struct pkg_t *grab_binpkg_info(const char *);
+static char *find_binpkg(const char *);
 
-_q_static void fetch(const char *destdir, const char *src)
+static void
+fetch(const char *destdir, const char *src)
 {
 	if (!binhost[0])
 		return;
@@ -169,7 +167,8 @@ _q_static void fetch(const char *destdir, const char *src)
 	fflush(stderr);
 }
 
-_q_static void qmerge_initialize(void)
+static void
+qmerge_initialize(void)
 {
 	if (strlen(BUSYBOX))
 		if (access(BUSYBOX, X_OK) != 0)
@@ -208,13 +207,15 @@ struct qmerge_bv_state {
 	char *retbuf;
 };
 
-_q_static int qmerge_filter_cat(q_vdb_cat_ctx *cat_ctx, void *priv)
+static int
+qmerge_filter_cat(q_vdb_cat_ctx *cat_ctx, void *priv)
 {
 	struct qmerge_bv_state *state = priv;
 	return !state->catname || strcmp(cat_ctx->name, state->catname) == 0;
 }
 
-_q_static int qmerge_best_version_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
+static int
+qmerge_best_version_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 {
 	struct qmerge_bv_state *state = priv;
 	if (qlist_match(pkg_ctx, state->buf, NULL, true))
@@ -223,7 +224,8 @@ _q_static int qmerge_best_version_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 	return 0;
 }
 
-_q_static char *best_version(const char *catname, const char *pkgname)
+static char *
+best_version(const char *catname, const char *pkgname)
 {
 	static int vdb_check = 1;
 	static char retbuf[4096];
@@ -258,7 +260,7 @@ _q_static char *best_version(const char *catname, const char *pkgname)
 	return retbuf;
 }
 
-_q_static int
+static int
 config_protected(const char *buf, int cp_argc, char **cp_argv,
                  int cpm_argc, char **cpm_argv)
 {
@@ -284,7 +286,8 @@ config_protected(const char *buf, int cp_argc, char **cp_argv,
 	return 0;
 }
 
-_q_static void crossmount_rm(const char *fname, const struct stat st)
+static void
+crossmount_rm(const char *fname, const struct stat * const st)
 {
 	struct stat lst;
 
@@ -292,7 +295,7 @@ _q_static void crossmount_rm(const char *fname, const struct stat st)
 
 	if (lstat(fname, &lst) == -1)
 		return;
-	if (lst.st_dev != st.st_dev) {
+	if (lst.st_dev != st->st_dev) {
 		warn("skipping crossmount install masking: %s", fname);
 		return;
 	}
@@ -300,8 +303,8 @@ _q_static void crossmount_rm(const char *fname, const struct stat st)
 	rm_rf(fname);
 }
 
-void install_mask_pwd(int iargc, char **iargv, const struct stat st);
-void install_mask_pwd(int iargc, char **iargv, const struct stat st)
+static void
+install_mask_pwd(int iargc, char **iargv, const struct stat * const st)
 {
 	char buf[1024];
 	int i;
@@ -332,7 +335,7 @@ void install_mask_pwd(int iargc, char **iargv, const struct stat st)
 	}
 }
 
-_q_static char *
+static char *
 atom2str(const depend_atom *atom, char *buf, size_t size)
 {
 	if (atom->PR_int)
@@ -342,7 +345,7 @@ atom2str(const depend_atom *atom, char *buf, size_t size)
 	return buf;
 }
 
-_q_static char
+static char
 qprint_tree_node(int level, const depend_atom *atom, const struct pkg_t *pkg)
 {
 	char buf[1024];
@@ -410,7 +413,7 @@ qprint_tree_node(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	return c;
 }
 
-_q_static void
+static void
 pkg_run_func_at(int dirfd, const char *vdb_path, const char *phases, const char *func, const char *D, const char *T)
 {
 	const char *phase;
@@ -484,7 +487,7 @@ pkg_run_func_at(int dirfd, const char *vdb_path, const char *phases, const char
 #define pkg_run_func(...) pkg_run_func_at(AT_FDCWD, __VA_ARGS__)
 
 /* Copy one tree (the single package) to another tree (ROOT) */
-_q_static int
+static int
 merge_tree_at(int fd_src, const char *src, int fd_dst, const char *dst,
               FILE *contents, queue **objs, char **cpathp, int iargc, char **iargv,
               int cp_argc, char **cp_argv, int cpm_argc, char **cpm_argv)
@@ -721,7 +724,7 @@ merge_tree_at(int fd_src, const char *src, int fd_dst, const char *dst,
 }
 
 /* Copy one tree (the single package) to another tree (ROOT) */
-_q_static int
+static int
 merge_tree(const char *src, const char *dst, FILE *contents,
            queue **objs, int iargc, char **iargv)
 {
@@ -749,7 +752,7 @@ merge_tree(const char *src, const char *dst, FILE *contents,
 }
 
 /* oh shit getting into pkg mgt here. FIXME: write a real dep resolver. */
-_q_static void
+static void
 pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 {
 	queue *objs;
@@ -771,7 +774,7 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	if (!install || !pkg || !atom)
 		return;
 
-	if (!pkg->PF[0] || !pkg->CATEGORY) {
+	if (!pkg->PF[0] || !pkg->CATEGORY[0]) {
 		if (verbose) warn("CPF is really NULL at level %d", level);
 		return;
 	}
@@ -899,11 +902,13 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 
 	/* split the tbz and xpak data */
 	xasprintf(&tbz2, "%s/%s/%s.tbz2", pkgdir, pkg->CATEGORY, pkg->PF);
-	assert(run_applet_l("qtbz2", "-s", tbz2, NULL) == 0);
+	if (run_applet_l("qtbz2", "-s", tbz2, NULL) != 0)
+		err("`qtbz2 -s %s` failed", tbz2);
 
 	mkdir("vdb", 0755);
 	sprintf(tbz2, "%s.xpak", pkg->PF);
-	assert(run_applet_l("qxpak", "-d", "vdb", "-x", tbz2, NULL) == 0);
+	if (run_applet_l("qxpak", "-d", "vdb", "-x", tbz2, NULL) != 0)
+		err("`qxpak -d vdb -x %s` failed", tbz2);
 
 	free(tbz2);
 
@@ -928,7 +933,7 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	makeargv(install_mask, &iargc, &iargv);
 	/* XXX: Would be better if INSTALL_MASK deleted from image/
 	 *      so we didn't have to parse it while doing merge_tree() */
-	install_mask_pwd(iargc, iargv, st);
+	install_mask_pwd(iargc, iargv, &st);
 
 	if (strstr(features, "noinfo")) rm_rf("./usr/share/info");
 	if (strstr(features, "noman" )) rm_rf("./usr/share/man");
@@ -1027,7 +1032,7 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	q_vdb_close(vdb_ctx);
 }
 
-_q_static int
+static int
 pkg_unmerge(q_vdb_pkg_ctx *pkg_ctx, queue *keep)
 {
 	q_vdb_cat_ctx *cat_ctx = pkg_ctx->cat_ctx;
@@ -1210,7 +1215,8 @@ pkg_unmerge(q_vdb_pkg_ctx *pkg_ctx, queue *keep)
 	return ret;
 }
 
-_q_static int unlink_empty(const char *buf)
+static int
+unlink_empty(const char *buf)
 {
 	struct stat st;
 	if (stat(buf, &st) != -1)
@@ -1219,7 +1225,7 @@ _q_static int unlink_empty(const char *buf)
 	return -1;
 }
 
-_q_static int
+static int
 pkg_verify_checksums(char *fname, const struct pkg_t *pkg, const depend_atom *atom,
                      int strict, int display)
 {
@@ -1263,7 +1269,7 @@ pkg_verify_checksums(char *fname, const struct pkg_t *pkg, const depend_atom *at
 	return ret;
 }
 
-_q_static void
+static void
 pkg_fetch(int level, const depend_atom *atom, const struct pkg_t *pkg)
 {
 	char buf[_Q_PATH_MAX], str[_Q_PATH_MAX];
@@ -1333,7 +1339,7 @@ pkg_fetch(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	}
 }
 
-_q_static void
+static void
 print_Pkg(int full, const depend_atom *atom, const struct pkg_t *pkg)
 {
 	char *p = NULL;
@@ -1383,7 +1389,7 @@ print_Pkg(int full, const depend_atom *atom, const struct pkg_t *pkg)
 	}
 }
 
-_q_static int
+static int
 qmerge_unmerge_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 {
 	queue *todo = priv;
@@ -1397,13 +1403,13 @@ qmerge_unmerge_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 	return 0;
 }
 
-_q_static int
+static int
 unmerge_packages(queue *todo)
 {
 	return q_vdb_foreach_pkg(qmerge_unmerge_cb, todo, NULL);
 }
 
-_q_static FILE *
+static FILE *
 open_binpkg_index(void)
 {
 	FILE *fp;
@@ -1454,7 +1460,7 @@ open_binpkg_index(void)
 	return fp;
 }
 
-_q_static struct pkg_t *
+static struct pkg_t *
 grab_binpkg_info(const char *name)
 {
 	FILE *fp;
@@ -1556,7 +1562,7 @@ grab_binpkg_info(const char *name)
 	return rpkg;
 }
 
-_q_static char *
+static char *
 find_binpkg(const char *name)
 {
 	FILE *fp;
@@ -1637,7 +1643,7 @@ find_binpkg(const char *name)
 	return best_match;
 }
 
-_q_static int
+static int
 parse_packages(queue *todo)
 {
 	FILE *fp;
@@ -1769,7 +1775,7 @@ parse_packages(queue *todo)
 	return EXIT_SUCCESS;
 }
 
-_q_static queue *
+static queue *
 qmerge_add_set_file(const char *dir, const char *file, queue *set)
 {
 	FILE *fp;
@@ -1799,7 +1805,7 @@ qmerge_add_set_file(const char *dir, const char *file, queue *set)
 	return set;
 }
 
-_q_static void *
+static void *
 qmerge_add_set_system(void *data, char *buf)
 {
 	queue *set = data;
@@ -1824,7 +1830,7 @@ qmerge_add_set_system(void *data, char *buf)
 /* XXX: note, this doesn't handle more complicated set files like
  *      the portage .ini files in /usr/share/portage/sets/ */
 /* XXX: this code does not combine duplicate dependencies */
-_q_static queue *
+static queue *
 qmerge_add_set(char *buf, queue *set)
 {
 	if (strcmp(buf, "world") == 0)
@@ -1839,7 +1845,7 @@ qmerge_add_set(char *buf, queue *set)
 		return add_set(buf, set);
 }
 
-_q_static int
+static int
 qmerge_run(queue *todo)
 {
 	if (uninstall)
@@ -1865,7 +1871,9 @@ int qmerge_main(int argc, char **argv)
 			case 'K': install = 1; break;
 			case 'U': uninstall = 1; break;
 			case 'p': pretend = 1; break;
-			case 'u': update_only = 1;
+			case 'u':
+				update_only = 1;
+				/* fall through */
 			case 'y': interactive = 0; break;
 			case 'O': follow_rdepends = 0; break;
 			case 128: debug = true; break;
