@@ -49,8 +49,8 @@ static const char * const qtbz2_opts_help[] = {
 
 static char tbz2_stdout = 0;
 
-unsigned char *tbz2_encode_int(int enc);
-unsigned char *tbz2_encode_int(int enc)
+static unsigned char *
+tbz2_encode_int(int enc)
 {
 	static unsigned char ret[4];
 	ret[0] = (enc & 0xff000000) >> 24;
@@ -59,8 +59,8 @@ unsigned char *tbz2_encode_int(int enc)
 	ret[3] = (enc & 0x000000ff);
 	return ret;
 }
-int tbz2_decode_int(unsigned char *buf);
-int tbz2_decode_int(unsigned char *buf)
+static int
+tbz2_decode_int(unsigned char *buf)
 {
 	int ret;
 	ret = 0;
@@ -71,8 +71,8 @@ int tbz2_decode_int(unsigned char *buf)
 	return ret;
 }
 
-void _tbz2_copy_file(FILE *src, FILE *dst);
-void _tbz2_copy_file(FILE *src, FILE *dst)
+static void
+_tbz2_copy_file(FILE *src, FILE *dst)
 {
 	int count = 1;
 	unsigned char buffer[BUFSIZE*32];
@@ -252,13 +252,15 @@ int qtbz2_main(int argc, char **argv)
 		COMMON_GETOPTS_CASES(qtbz2)
 		case 'j': action = TBZ2_ACT_JOIN; break;
 		case 's': action = TBZ2_ACT_SPLIT; break;
-		case 't': split_xpak = 0; break;
-		case 'x': split_tarbz2 = 0; break;
+		case 't': action = TBZ2_ACT_SPLIT; split_xpak = 0; break;
+		case 'x': action = TBZ2_ACT_SPLIT; split_tarbz2 = 0; break;
 		case 'O': tbz2_stdout = 1; break;
 		case 'd':
 			if (dir_fd != AT_FDCWD)
-				err("Only use -d once");
+				close(dir_fd);
 			dir_fd = open(optarg, O_RDONLY|O_CLOEXEC|O_PATH);
+			if (unlikely(dir_fd == -1))
+				errp("could not open dir: %s", optarg);
 			break;
 		}
 	}
@@ -279,7 +281,8 @@ int qtbz2_main(int argc, char **argv)
 		else if (strstr(argv[optind], ".tbz2") != NULL)
 			action = TBZ2_ACT_SPLIT;
 		else
-			qtbz2_usage(EXIT_FAILURE);
+			err("%s: need to use -j or -s, or file must end in .tar.bz2 or .tbz2 to autodetect",
+				argv[optind]);
 	}
 
 	/* tbz2tool join .tar.bz2 .xpak .tbz2 */
@@ -353,9 +356,14 @@ int qtbz2_main(int argc, char **argv)
 			warn("Could not decompose '%s'", tbz2);
 	}
 
+	/* We have to cleanup all resources as we're used indirectly
+	 * (e.g. via qmerge).
+	 */
 	free(heap_tbz2);
 	free(heap_xpak);
 	free(heap_tarbz2);
+	if (dir_fd != AT_FDCWD)
+		close(dir_fd);
 
 	return EXIT_SUCCESS;
 }
