@@ -154,6 +154,7 @@ xpak_list(int dir_fd, const char *file, int argc, char **argv)
 {
 	_xpak_archive *x;
 	char buf[BUFSIZE];
+	size_t ret;
 
 	x = _xpak_open(file);
 	if (!x)
@@ -162,7 +163,8 @@ xpak_list(int dir_fd, const char *file, int argc, char **argv)
 	x->dir_fd = dir_fd;
 	x->index = buf;
 	assert((size_t)x->index_len < sizeof(buf));
-	assert(fread(x->index, 1, x->index_len, x->fp) == (size_t)x->index_len);
+	ret = fread(x->index, 1, x->index_len, x->fp);
+	assert(ret == (size_t)x->index_len);
 	_xpak_walk_index(x, argc, argv, &_xpak_list_callback);
 
 	_xpak_close(x);
@@ -339,8 +341,15 @@ xpak_create(int dir_fd, const char *file, int argc, char **argv)
 			if ((numfiles = scandir(argv[i], &dir, filter_hidden, alphasort)) < 0)
 				warn("Directory '%s' is empty; skipping", argv[i]);
 			for (fidx = 0; fidx < numfiles; ++fidx) {
-				snprintf(path, sizeof(path), "%s/%s", argv[i], dir[fidx]->d_name);
-				stat(path, &st);
+				int ret = snprintf(path, sizeof(path), "%s/%s", argv[i], dir[fidx]->d_name);
+				if (ret >= sizeof(path)) {
+					warn("skipping path too long: %s/%s", argv[i], dir[fidx]->d_name);
+					continue;
+				}
+				if (stat(path, &st) < 0) {
+					warnp("could not read %s", path);
+					continue;
+				}
 				_xpak_add_file(dir_fd, path, &st, findex, &index_len, fdata, &data_len);
 			}
 			scandir_free(dir, numfiles);
